==> linuxconf-1.17.src.tar.gz: linuxconf-1.17/modules/samba/samba.pm <==
/* _dict.cc 07/10/97 20.14.38 */
/* internal.cc 07/10/97 12.54.18 */
PUBLIC SAMBA_HELP_FILE::SAMBA_HELP_FILE (const char *fname);
/* keyword.cc 31/08/99 00.46.42 */
/* samba.cc 18/08/99 00.11.28 */
PUBLIC MODULE_SAMBA::MODULE_SAMBA (void);
PUBLIC void MODULE_SAMBA::setmenu (DIALOG&dia, MENU_CONTEXT context);
PUBLIC int MODULE_SAMBA::domenu (MENU_CONTEXT context, const char *key);
PUBLIC int MODULE_SAMBA::message (const char *msg,
	 int argc,
	 const char *argv[]);
PUBLIC void MODULE_SAMBA::usage (SSTRINGS&tb);
PUBLIC int MODULE_SAMBA::execmain (int argc, char *argv[]);
/* samedit.cc 31/08/99 01.20.30 */
PRIVATE void SMB_SHARE::setdia (DIALOG&dia,
	 SMB_FIELD tbf[],
	 int nbf,
	 SMB_FIELD_VAL tbv[]);
PRIVATE void SMB_SHARE::savedia (SMB_FIELD tbf[],
	 int nbf,
	 SMB_FIELD_VAL tbv[]);
PUBLIC int SMB_SHARE::editgen (DIALOG&dia,
	 SMB_FIELD tbf[],
	 int nbf,
	 bool may_del,
	 SAMBA_HELP_FILE&help_file);
PUBLIC int SMB_SHARE::edit (void);
PUBLIC int SMB_SHARE::editglobal (void);
PUBLIC int SMB_SHARE::editnetlogon (SMB_SHARE *glob);
PUBLIC int SMB_SHARE::edithomes (void);
PUBLIC int SMB_SHARE::editprinters (void);
PUBLIC int SMB_SHARES::write (void);
PUBLIC int SMB_CONF::editshares (void);
PUBLIC void SMB_CONF::editdefaults (void);
PUBLIC void SMB_CONF::edithomes (void);
PUBLIC void SMB_CONF::editprinters (void);
PUBLIC void SMB_CONF::editnetlogon (void);
PUBLIC void SMB_CONF::edit (void);
/* smbconf.cc 23/05/99 21.08.30 */
PUBLIC SMB_ITEM::SMB_ITEM (void);
PUBLIC SMB_ITEM::SMB_ITEM (const char *_comment, const char *line);
PUBLIC void SMB_ITEM::write (FILE *fout)const;
PUBLIC SMB_ITEM *SMB_ITEMS::getitem (int no)const;
PUBLIC SMB_ITEM *SMB_ITEMS::getitem (const char *key)const;
PUBLIC const char *SMB_ITEMS::getval (const char *key)const;
PUBLIC const char *SMB_ITEMS::getval (const char *key1,
	 const char *key2,
	 const char *key3)const;
PUBLIC void SMB_ITEMS::setval (const char *key, const char *val);
PUBLIC void SMB_ITEMS::setval (const char *key, const SSTRING&val);
PUBLIC void SMB_ITEMS::setval (const char *key, int num);
PUBLIC void SMB_ITEMS::setval (const char *key1,
	 const char *key2,
	 const char *key3,
	 const char *val);
PUBLIC void SMB_ITEMS::setval (const char *key1,
	 const char *key2,
	 const char *key3,
	 const SSTRING&val);
PUBLIC void SMB_ITEMS::setval (const char *key1,
	 const char *key2,
	 const char *key3,
	 int num);
PUBLIC void SMB_ITEMS::write (FILE *fout)const;
PUBLIC SMB_SHARE::SMB_SHARE (const char *_comment, const char *_name);
PUBLIC SMB_SHARE::SMB_SHARE (void);
PUBLIC const char *SMB_SHARE::getval (const char *key)const;
PUBLIC const char *SMB_SHARE::getval (const char *key1,
	 const char *key2,
	 const char *key3)const;
PUBLIC void SMB_SHARE::setval (const char *key, const SSTRING&val);
PUBLIC void SMB_SHARE::setval (const char *key, int num);
PUBLIC void SMB_SHARE::setval (const char *key1,
	 const char *key2,
	 const char *key3,
	 const SSTRING&val);
PUBLIC void SMB_SHARE::setval (const char *key1,
	 const char *key2,
	 const char *key3,
	 int num);
PUBLIC void SMB_SHARE::setval (const char *key1,
	 const char *key2,
	 const char *key3,
	 const char *val);
PUBLIC void SMB_SHARE::write (FILE *fout)const;
PUBLIC SMB_SHARE *SMB_SHARES::getitem (int no)const;
PUBLIC SMB_SHARE *SMB_SHARES::getitem (const char *name)const;
PUBLIC SMB_CONF::SMB_CONF (void);
PUBLIC int SMB_CONF::write (void);
/* status.cc 28/04/99 15.53.16 */

==> linuxconf-1.19.src.tar.gz: linuxconf-1.19/modules/samba/samba.pm <==
/* _dict.cc 07/10/1997 20.14.38 */
/* internal.cc 07/10/1997 12.54.18 */
PUBLIC SAMBA_HELP_FILE::SAMBA_HELP_FILE (const char *fname);
/* keyword.cc 29/03/2000 23.51.12 */
/* samba.cc 24/01/2000 23.01.14 */
PUBLIC MODULE_SAMBA::MODULE_SAMBA (void);
PUBLIC void MODULE_SAMBA::setmenu (DIALOG&dia, MENU_CONTEXT context);
PUBLIC int MODULE_SAMBA::domenu (MENU_CONTEXT context, const char *key);
PUBLIC int MODULE_SAMBA::message (const char *msg,
	 int argc,
	 const char *argv[]);
PUBLIC void MODULE_SAMBA::usage (SSTRINGS&tb);
PUBLIC int MODULE_SAMBA::execmain (int argc, char *argv[]);
/* samedit.cc 21/06/2000 17.49.52 */
PRIVATE void SMB_SHARE::setdia (DIALOG&dia,
	 SMB_FIELD tbf[],
	 int nbf,
	 SMB_FIELD_VAL tbv[]);
PRIVATE void SMB_SHARE::savedia (SMB_FIELD tbf[],
	 int nbf,
	 SMB_FIELD_VAL tbv[]);
PUBLIC int SMB_SHARE::editgen (DIALOG&dia,
	 SMB_FIELD tbf[],
	 int nbf,
	 bool may_del,
	 SAMBA_HELP_FILE&help_file);
PUBLIC int SMB_SHARE::edit (void);
PUBLIC int SMB_SHARE::editglobal (SMB_CONF *samba);
PUBLIC int SMB_SHARE::editnetlogon (SMB_SHARE *glob, SMB_CONF *samba);
PUBLIC int SMB_SHARE::edithomes (SMB_CONF *samba);
PUBLIC int SMB_SHARE::editprinters (SMB_CONF *samba);
PUBLIC int SMB_SHARES::write (void);
PUBLIC int SMB_CONF::editshares (void);
PUBLIC void SMB_CONF::editdefaults (void);
PUBLIC void SMB_CONF::edithomes (void);
PUBLIC void SMB_CONF::editprinters (void);
PUBLIC void SMB_CONF::editnetlogon (void);
PUBLIC void SMB_CONF::edit (void);
/* smbconf.cc 21/06/2000 17.48.20 */
PUBLIC SMB_ITEM::SMB_ITEM (void);
PUBLIC SMB_ITEM::SMB_ITEM (const char *_comment, const char *line);
PUBLIC void SMB_ITEM::write (FILE *fout)const;
PUBLIC SMB_ITEM *SMB_ITEMS::getitem (int no)const;
PUBLIC SMB_ITEM *SMB_ITEMS::getitem (const char *key)const;
PUBLIC const char *SMB_ITEMS::getval (const char *key)const;
PUBLIC const char *SMB_ITEMS::getval (const char *key1,
	 const char *key2,
	 const char *key3)const;
PUBLIC void SMB_ITEMS::setval (const char *key, const char *val);
PUBLIC void SMB_ITEMS::setval (const char *key, const SSTRING&val);
PUBLIC void SMB_ITEMS::setval (const char *key, int num);
PUBLIC void SMB_ITEMS::setval (const char *key1,
	 const char *key2,
	 const char *key3,
	 const char *val);
PUBLIC void SMB_ITEMS::setval (const char *key1,
	 const char *key2,
	 const char *key3,
	 const SSTRING&val);
PUBLIC void SMB_ITEMS::setval (const char *key1,
	 const char *key2,
	 const char *key3,
	 int num);
PUBLIC void SMB_ITEMS::write (FILE *fout)const;
PUBLIC SMB_SHARE::SMB_SHARE (const char *_comment, const char *_name);
PUBLIC SMB_SHARE::SMB_SHARE (void);
PUBLIC const char *SMB_SHARE::getval (const char *key)const;
PUBLIC const char *SMB_SHARE::getval (const char *key1,
	 const char *key2,
	 const char *key3)const;
PUBLIC void SMB_SHARE::setval (const char *key, const SSTRING&val);
PUBLIC void SMB_SHARE::setval (const char *key, int num);
PUBLIC void SMB_SHARE::setval (const char *key1,
	 const char *key2,
	 const char *key3,
	 const SSTRING&val);
PUBLIC void SMB_SHARE::setval (const char *key1,
	 const char *key2,
	 const char *key3,
	 int num);
PUBLIC void SMB_SHARE::setval (const char *key1,
	 const char *key2,
	 const char *key3,
	 const char *val);
PUBLIC void SMB_SHARE::write (FILE *fout)const;
PUBLIC SMB_SHARE *SMB_SHARES::getitem (int no)const;
PUBLIC SMB_SHARE *SMB_SHARES::getitem (const char *name)const;
PUBLIC SMB_SHARES::SMB_SHARES (SMB_CONF *_samba);
PUBLIC SMB_CONF::SMB_CONF (void);
PUBLIC int SMB_CONF::write (void);
PUBLIC int SMB_CONF::sanitycheck (void);
/* status.cc 28/04/1999 15.53.16 */
